@@ -1,3 +1,17 @@
+/*
+ * Copyright (C) 2008-2011 Robert Ancell.
+ *
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 2 of the License, or (at your option) any later
+ * version. See http://www.gnu.org/copyleft/gpl.html the full text of the
+ * license.
+ */
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <time.h>
 
 #include <glib.h>
@@ -124,13 +138,17 @@ currency_manager_get_default(void)
 GList *
 currency_manager_get_currencies(CurrencyManager *manager)
 {
-     return manager->priv->currencies;
+    g_return_val_if_fail(manager != NULL, NULL);
+    return manager->priv->currencies;
 }
 
 
 Currency *
 currency_manager_get_currency(CurrencyManager *manager, const gchar *name)
 {
+    g_return_val_if_fail(manager != NULL, NULL);
+    g_return_val_if_fail(name != NULL, NULL);
+
     GList *link;
     for (link = manager->priv->currencies; link; link = link->next) {
         Currency *c = link->data;
@@ -384,6 +402,7 @@ load_imf_rates(CurrencyManager *manager)
                         c = add_currency(manager, name_map[name_index].symbol);
                     }
                     mp_set_from_string(tokens[value_index], 10, &value);
+                    mp_reciprocal(&value, &value);
                     currency_set_value(c, &value);
                 }
                 else
@@ -423,7 +442,7 @@ set_ecb_rate(CurrencyManager *manager, xmlNodePtr node, Currency *eur_rate)
         c = add_currency(manager, name);
         mp_set_from_string(value, 10, &r);
         mp_set_from_mp(currency_get_value(eur_rate), &v);
-        mp_divide(&v, &r, &v);
+        mp_multiply(&v, &r, &v);
         currency_set_value(c, &v);
     }
 
@@ -467,7 +486,7 @@ load_ecb_rates(CurrencyManager *manager)
     }
 
     /* Set some fixed rates */
-    set_ecb_fixed_rate(manager, "EEK", "15.6466", eur_rate);
+    set_ecb_fixed_rate(manager, "EEK", "0.06391", eur_rate);
 
     xmlInitParser();
     document = xmlReadFile(filename, NULL, 0);
@@ -555,6 +574,9 @@ currency_manager_get_value(CurrencyManager *manager, const gchar *currency)
     gchar *path;
     Currency *c;
 
+    g_return_val_if_fail(manager != NULL, NULL);
+    g_return_val_if_fail(currency != NULL, NULL);
+
     /* Update rates if necessary */
     path = get_imf_rate_filepath();
     if (!downloading_imf_rates && file_needs_update(path, 60 * 60 * 24 * 7)) {
@@ -573,9 +595,12 @@ currency_manager_get_value(CurrencyManager *manager, const gchar *currency)
 
     if (!load_rates(manager))
         return NULL;
-  
+
     c = currency_manager_get_currency(manager, currency);
-    return currency_get_value(c);
+    if (c)
+        return currency_get_value(c);
+    else
+        return NULL;
 }
 
 
