@@ -363,6 +363,8 @@ test_equations()
     test("1+(2×3)", "7", 0);
     test("(1+2)×3", "9", 0);
     test("(1+2×3)", "7", 0);
+    test("2(1+1)", "4", 0);
+    test("4÷2(1+1)", "4", 0);
 
     /* Percentage */
     test("100%", "1", 0);
@@ -391,6 +393,7 @@ test_equations()
     test("|1−3|²", "4", 0);
     test("|x|²", "4", 0);
     test("0^0", "1", 0);
+    test("0^0.5", "0", 0);
     test("2^0", "1", 0);
     test("2^1", "2", 0);
     test("2^2", "4", 0);
